@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2014-08-23'; # DATE
-our $VERSION = '0.17'; # VERSION
+our $DATE = '2014-08-24'; # DATE
+our $VERSION = '0.18'; # VERSION
 
 use 5.010001;
 
@@ -372,14 +372,14 @@ sub run {
         }
     }
     $r->{format} //= $r->{res}[3]{'cmdline.default_format'};
-    if ($r->{res}[3]{'cmdline.result'}) {
+    if (exists $r->{res}[3]{'cmdline.result'}) {
         $r->{res}[2] = $r->{res}[3]{'cmdline.result'};
     }
   FORMAT:
-    if (!$r->{res}[3]{'cmdline.skip_format'}) {
-        $r->{fres} = $self->hook_format_result($r) // '';
-    } else {
+    if ($r->{res}[3]{'cmdline.skip_format'}) {
         $r->{fres} = $r->{res};
+    } else {
+        $r->{fres} = $self->hook_format_result($r) // '';
     }
     $self->hook_display_result($r);
     $self->hook_after_run($r);
@@ -414,7 +414,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{,::Lite}
 
 =head1 VERSION
 
-This document describes version 0.17 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2014-08-23.
+This document describes version 0.18 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2014-08-24.
 
 =for Pod::Coverage ^(.+)$
 
